@@ -18,7 +18,7 @@ class JenkinsCreateJobTest(JenkinsJobsTestBase):
         self.j.create_job(u'Test Job', self.config_xml)
 
         self.assertEqual(
-            jenkins_mock.call_args_list[1][0][0].get_full_url(),
+            jenkins_mock.call_args_list[1][0][0].url,
             self.make_url('createItem?name=Test%20Job'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -33,7 +33,7 @@ class JenkinsCreateJobTest(JenkinsJobsTestBase):
         self.j.create_job(u'a Folder/Test Job', self.config_xml)
 
         self.assertEqual(
-            jenkins_mock.call_args_list[1][0][0].get_full_url(),
+            jenkins_mock.call_args_list[1][0][0].url,
             self.make_url('job/a%20Folder/createItem?name=Test%20Job'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -47,7 +47,7 @@ class JenkinsCreateJobTest(JenkinsJobsTestBase):
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.create_job(u'TestJob', self.config_xml)
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/TestJob/api/json?tree=name'))
         self.assertEqual(
             str(context_manager.exception),
@@ -64,7 +64,7 @@ class JenkinsCreateJobTest(JenkinsJobsTestBase):
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.create_job(u'a Folder/TestJob', self.config_xml)
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/a%20Folder/job/TestJob/api/json?tree=name'))
         self.assertEqual(
             str(context_manager.exception),
@@ -82,10 +82,10 @@ class JenkinsCreateJobTest(JenkinsJobsTestBase):
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.create_job(u'TestJob', self.config_xml)
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/TestJob/api/json?tree=name'))
         self.assertEqual(
-            jenkins_mock.call_args_list[1][0][0].get_full_url(),
+            jenkins_mock.call_args_list[1][0][0].url,
             self.make_url('createItem?name=TestJob'))
         self.assertEqual(
             str(context_manager.exception),
@@ -103,10 +103,10 @@ class JenkinsCreateJobTest(JenkinsJobsTestBase):
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.create_job(u'a Folder/TestJob', self.config_xml)
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/a%20Folder/job/TestJob/api/json?tree=name'))
         self.assertEqual(
-            jenkins_mock.call_args_list[1][0][0].get_full_url(),
+            jenkins_mock.call_args_list[1][0][0].url,
             self.make_url('job/a%20Folder/createItem?name=TestJob'))
         self.assertEqual(
             str(context_manager.exception),
