@@ -18,7 +18,7 @@ class JenkinsRenameJobTest(JenkinsJobsTestBase):
         self.j.rename_job(u'Test Job', u'Test Job_2')
 
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/Test%20Job/doRename?newName=Test%20Job_2'))
         self.assertTrue(self.j.job_exists('Test Job_2'))
         self._check_requests(jenkins_mock.call_args_list)
@@ -34,7 +34,7 @@ class JenkinsRenameJobTest(JenkinsJobsTestBase):
         self.j.rename_job(u'a Folder/Test Job', u'a Folder/Test Job_2')
 
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/a%20Folder/job/Test%20Job/doRename?newName=Test%20Job_2'))
         self.assertTrue(self.j.job_exists('Test Job_2'))
         self._check_requests(jenkins_mock.call_args_list)
@@ -49,7 +49,7 @@ class JenkinsRenameJobTest(JenkinsJobsTestBase):
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.rename_job(u'TestJob', u'TestJob_2')
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/TestJob/doRename?newName=TestJob_2'))
         self.assertEqual(
             str(context_manager.exception),
@@ -66,7 +66,7 @@ class JenkinsRenameJobTest(JenkinsJobsTestBase):
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.rename_job(u'a Folder/TestJob', u'a Folder/TestJob_2')
         self.assertEqual(
-            jenkins_mock.call_args_list[0][0][0].get_full_url(),
+            jenkins_mock.call_args_list[0][0][0].url,
             self.make_url('job/a%20Folder/job/TestJob/doRename?newName=TestJob_2'))
         self.assertEqual(
             str(context_manager.exception),
