@@ -1,8 +1,11 @@
 import json
+
+import collections
 from mock import patch
 
 import jenkins
 from tests.base import JenkinsTestBase
+from tests.helper import build_response_mock
 
 
 class JenkinsBuildConsoleTest(JenkinsTestBase):
@@ -15,7 +18,7 @@ class JenkinsBuildConsoleTest(JenkinsTestBase):
 
         self.assertEqual(build_info, jenkins_mock.return_value)
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/Test%20Job/52/consoleText'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -27,7 +30,7 @@ class JenkinsBuildConsoleTest(JenkinsTestBase):
 
         self.assertEqual(build_info, jenkins_mock.return_value)
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/a%20Folder/job/Test%20Job/52/consoleText'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -59,45 +62,38 @@ class JenkinsBuildConsoleTest(JenkinsTestBase):
 
         console_output = self.j.get_build_console_output(u'TestJob', number=52)
         self.assertEqual(console_output, jenkins_mock.return_value)
-        self._check_requests(jenkins_mock.call_args_list)
 
-    @patch.object(jenkins.Jenkins, 'jenkins_open')
-    def test_raise_HTTPError(self, jenkins_mock):
-        jenkins_mock.side_effect = jenkins.HTTPError(
-            self.make_url('job/TestJob/52/consoleText'),
-            code=401,
-            msg="basic auth failed",
-            hdrs=[],
-            fp=None)
+    @patch('jenkins.requests.Session.send')
+    def test_raise_HTTPError(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(404, reason="Not Found"),  # crumb
+            build_response_mock(404, reason="Not Found"),  # request
+        ])
 
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.get_build_console_output(u'TestJob', number=52)
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            session_send_mock.call_args_list[1][0][0].url,
             self.make_url('job/TestJob/52/consoleText'))
         self.assertEqual(
             str(context_manager.exception),
             'job[TestJob] number[52] does not exist')
-        self._check_requests(jenkins_mock.call_args_list)
 
-    @patch.object(jenkins.Jenkins, 'jenkins_open')
-    def test_in_folder_raise_HTTPError(self, jenkins_mock):
-        jenkins_mock.side_effect = jenkins.HTTPError(
-            self.make_url('job/a%20Folder/job/TestJob/52/consoleText'),
-            code=401,
-            msg="basic auth failed",
-            hdrs=[],
-            fp=None)
+    @patch('jenkins.requests.Session.send')
+    def test_in_folder_raise_HTTPError(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(404, reason="Not Found"),  # crumb
+            build_response_mock(404, reason="Not Found"),  # request
+        ])
 
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.get_build_console_output(u'a Folder/TestJob', number=52)
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            session_send_mock.call_args_list[1][0][0].url,
             self.make_url('job/a%20Folder/job/TestJob/52/consoleText'))
         self.assertEqual(
             str(context_manager.exception),
             'job[a Folder/TestJob] number[52] does not exist')
-        self._check_requests(jenkins_mock.call_args_list)
 
 
 class JenkinsBuildInfoTest(JenkinsTestBase):
@@ -116,7 +112,7 @@ class JenkinsBuildInfoTest(JenkinsTestBase):
 
         self.assertEqual(build_info, build_info_to_return)
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/Test%20Job/52/api/json?depth=0'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -134,7 +130,7 @@ class JenkinsBuildInfoTest(JenkinsTestBase):
 
         self.assertEqual(build_info, build_info_to_return)
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/a%20Folder/job/Test%20Job/52/api/json?depth=0'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -160,37 +156,31 @@ class JenkinsBuildInfoTest(JenkinsTestBase):
             'Could not parse JSON info for job[TestJob] number[52]')
         self._check_requests(jenkins_mock.call_args_list)
 
-    @patch.object(jenkins.Jenkins, 'jenkins_open')
-    def test_raise_HTTPError(self, jenkins_mock):
-        jenkins_mock.side_effect = jenkins.HTTPError(
-            self.make_url('job/TestJob/api/json?depth=0'),
-            code=401,
-            msg="basic auth failed",
-            hdrs=[],
-            fp=None)
+    @patch('jenkins.requests.Session.send', autospec=True)
+    def test_raise_HTTPError(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(404, reason="Not Found"),  # crumb
+            build_response_mock(404, reason="Not Found"),  # request
+        ])
 
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.get_build_info(u'TestJob', number=52)
         self.assertEqual(
             str(context_manager.exception),
             'job[TestJob] number[52] does not exist')
-        self._check_requests(jenkins_mock.call_args_list)
 
-    @patch.object(jenkins.Jenkins, 'jenkins_open')
-    def test_in_folder_raise_HTTPError(self, jenkins_mock):
-        jenkins_mock.side_effect = jenkins.HTTPError(
-            self.make_url('job/a%20Folder/job/TestJob/api/json?depth=0'),
-            code=401,
-            msg="basic auth failed",
-            hdrs=[],
-            fp=None)
+    @patch('jenkins.requests.Session.send', autospec=True)
+    def test_in_folder_raise_HTTPError(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(404, reason="Not Found"),  # crumb
+            build_response_mock(404, reason="Not Found"),  # request
+        ])
 
         with self.assertRaises(jenkins.JenkinsException) as context_manager:
             self.j.get_build_info(u'a Folder/TestJob', number=52)
         self.assertEqual(
             str(context_manager.exception),
             'job[a Folder/TestJob] number[52] does not exist')
-        self._check_requests(jenkins_mock.call_args_list)
 
 
 class JenkinsStopBuildTest(JenkinsTestBase):
@@ -200,7 +190,7 @@ class JenkinsStopBuildTest(JenkinsTestBase):
         self.j.stop_build(u'Test Job', number=52)
 
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/Test%20Job/52/stop'))
         self._check_requests(jenkins_mock.call_args_list)
 
@@ -210,11 +200,33 @@ class JenkinsStopBuildTest(JenkinsTestBase):
         self.j.stop_build(u'a Folder/Test Job', number=52)
 
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('job/a%20Folder/job/Test%20Job/52/stop'))
         self._check_requests(jenkins_mock.call_args_list)
 
 
+class JenkinsDeleteBuildTest(JenkinsTestBase):
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_simple(self, jenkins_mock):
+        self.j.delete_build(u'Test Job', number=52)
+
+        self.assertEqual(
+            jenkins_mock.call_args[0][0].url,
+            self.make_url('job/Test%20Job/52/doDelete'))
+        self._check_requests(jenkins_mock.call_args_list)
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_in_folder(self, jenkins_mock):
+
+        self.j.delete_build(u'a Folder/Test Job', number=52)
+
+        self.assertEqual(
+            jenkins_mock.call_args[0][0].url,
+            self.make_url('job/a%20Folder/job/Test%20Job/52/doDelete'))
+        self._check_requests(jenkins_mock.call_args_list)
+
+
 class JenkinsListRunningBuildsTest(JenkinsTestBase):
     @patch.object(jenkins.Jenkins, 'get_node_info')
     @patch.object(jenkins.Jenkins, 'get_nodes')
@@ -454,3 +466,192 @@ class JenkinsListRunningBuildsTest(JenkinsTestBase):
         node_info_mock.return_value = node_info_to_return
         builds = self.j.get_running_builds()
         self.assertEqual([], builds)
+
+
+class JenkinsBuildJobUrlTest(JenkinsTestBase):
+
+    def test_params_as_dict(self):
+        token = 'token123'
+        params = [
+            ('m_select', 'value1'),
+            ('s_select', 's_select2')
+        ]
+        parameters = collections.OrderedDict(params)
+        self.assertEqual(
+            self.j.build_job_url('Test Job', parameters=parameters, token=token),
+            self.make_url(
+                'job/Test%20Job/buildWithParameters?m_select=value1'
+                '&s_select=s_select2&token=token123'))
+
+    def test_params_as_list(self):
+        token = 'token123'
+        params = [
+            ('m_select', 'value1',),
+            ('m_select', 'value3'),
+            ('s_select', 's_select2')
+        ]
+        self.assertEqual(
+            self.j.build_job_url('Test Job', parameters=params, token=token),
+            self.make_url(
+                'job/Test%20Job/buildWithParameters?m_select=value1'
+                '&m_select=value3&s_select=s_select2&token=token123'))
+
+
+class JenkinsBuildEnvVarUrlTest(JenkinsTestBase):
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_simple(self, jenkins_mock):
+        jenkins_mock.return_value = '{}'
+        ret = self.j.get_build_env_vars(u'Test Job', number=52, depth=1)
+        self.assertEqual(ret, json.loads(jenkins_mock.return_value))
+        self.assertEqual(
+            jenkins_mock.call_args[0][0].url,
+            self.make_url('job/Test%20Job/52/injectedEnvVars/api/json?depth=1'))
+        self._check_requests(jenkins_mock.call_args_list)
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_in_folder(self, jenkins_mock):
+        jenkins_mock.return_value = '{}'
+        ret = self.j.get_build_env_vars(u'a Folder/Test Job', number=52, depth=1)
+        self.assertEqual(ret, json.loads(jenkins_mock.return_value))
+        self.assertEqual(
+            jenkins_mock.call_args[0][0].url,
+            self.make_url('job/a%20Folder/job/Test%20Job/52/injectedEnvVars/api/json?depth=1'))
+        self._check_requests(jenkins_mock.call_args_list)
+
+    @patch('jenkins.requests.Session.send', autospec=True)
+    def test_return_none(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(404, reason="Not Found"),  # crumb
+            build_response_mock(404, reason="Not Found"),  # request
+        ])
+        ret = self.j.get_build_env_vars(u'TestJob', number=52)
+        self.assertIsNone(ret)
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_open_return_none(self, jenkins_mock):
+        jenkins_mock.return_value = None
+
+        with self.assertRaises(jenkins.JenkinsException) as context_manager:
+            self.j.get_build_env_vars(u'TestJob', number=52)
+        self.assertEqual(
+            str(context_manager.exception),
+            'job[TestJob] number[52] does not exist')
+        self._check_requests(jenkins_mock.call_args_list)
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_return_invalid_json(self, jenkins_mock):
+        jenkins_mock.return_value = 'Invalid JSON'
+
+        with self.assertRaises(jenkins.JenkinsException) as context_manager:
+            self.j.get_build_env_vars(u'TestJob', number=52)
+        self.assertEqual(
+            str(context_manager.exception),
+            'Could not parse JSON info for job[TestJob] number[52]')
+        self._check_requests(jenkins_mock.call_args_list)
+
+    @patch('jenkins.requests.Session.send', autospec=True)
+    def test_raise_HTTPError(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(401, reason="Not Authorised"),  # crumb
+            build_response_mock(401, reason="Not Authorised"),  # request
+        ])
+
+        with self.assertRaises(jenkins.JenkinsException) as context_manager:
+            self.j.get_build_env_vars(u'TestJob', number=52)
+        self.assertEqual(
+            str(context_manager.exception),
+            'Error in request. Possibly authentication failed [401]: Not Authorised')
+
+    @patch('jenkins.requests.Session.send', autospec=True)
+    def test_in_folder_raise_HTTPError(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(401, reason="Not Authorised"),  # crumb
+            build_response_mock(401, reason="Not Authorised"),  # request
+        ])
+
+        with self.assertRaises(jenkins.JenkinsException) as context_manager:
+            self.j.get_build_env_vars(u'a Folder/TestJob', number=52)
+        self.assertEqual(
+            str(context_manager.exception),
+            'Error in request. Possibly authentication failed [401]: Not Authorised')
+
+
+class JenkinsBuildTestReportUrlTest(JenkinsTestBase):
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_simple(self, jenkins_mock):
+        jenkins_mock.return_value = '{}'
+        ret = self.j.get_build_test_report(u'Test Job', number=52, depth=1)
+        self.assertEqual(ret, json.loads(jenkins_mock.return_value))
+        self.assertEqual(
+            jenkins_mock.call_args[0][0].url,
+            self.make_url('job/Test%20Job/52/testReport/api/json?depth=1'))
+        self._check_requests(jenkins_mock.call_args_list)
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_in_folder(self, jenkins_mock):
+        jenkins_mock.return_value = '{}'
+        ret = self.j.get_build_test_report(u'a Folder/Test Job', number=52, depth=1)
+        self.assertEqual(ret, json.loads(jenkins_mock.return_value))
+        self.assertEqual(
+            jenkins_mock.call_args[0][0].url,
+            self.make_url('job/a%20Folder/job/Test%20Job/52/testReport/api/json?depth=1'))
+        self._check_requests(jenkins_mock.call_args_list)
+
+    @patch('jenkins.requests.Session.send', autospec=True)
+    def test_return_none(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(404, reason="Not Found"),  # crumb
+            build_response_mock(404, reason="Not Found"),  # request
+        ])
+        ret = self.j.get_build_test_report(u'TestJob', number=52)
+        self.assertIsNone(ret)
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_open_return_none(self, jenkins_mock):
+        jenkins_mock.return_value = None
+
+        with self.assertRaises(jenkins.JenkinsException) as context_manager:
+            self.j.get_build_test_report(u'TestJob', number=52)
+        self.assertEqual(
+            str(context_manager.exception),
+            'job[TestJob] number[52] does not exist')
+        self._check_requests(jenkins_mock.call_args_list)
+
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_return_invalid_json(self, jenkins_mock):
+        jenkins_mock.return_value = 'Invalid JSON'
+
+        with self.assertRaises(jenkins.JenkinsException) as context_manager:
+            self.j.get_build_test_report(u'TestJob', number=52)
+        self.assertEqual(
+            str(context_manager.exception),
+            'Could not parse JSON info for job[TestJob] number[52]')
+        self._check_requests(jenkins_mock.call_args_list)
+
+    @patch('jenkins.requests.Session.send', autospec=True)
+    def test_raise_HTTPError(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(401, reason="Not Authorised"),  # crumb
+            build_response_mock(401, reason="Not Authorised"),  # request
+        ])
+
+        with self.assertRaises(jenkins.JenkinsException) as context_manager:
+            self.j.get_build_test_report(u'TestJob', number=52)
+        self.assertEqual(
+            str(context_manager.exception),
+            'Error in request. Possibly authentication failed [401]: Not Authorised')
+
+    @patch('jenkins.requests.Session.send', autospec=True)
+    def test_in_folder_raise_HTTPError(self, session_send_mock):
+        session_send_mock.side_effect = iter([
+            build_response_mock(401, reason="Not Authorised"),  # crumb
+            build_response_mock(401, reason="Not Authorised"),  # request
+        ])
+
+        with self.assertRaises(jenkins.JenkinsException) as context_manager:
+            self.j.get_build_test_report(u'a Folder/TestJob', number=52)
+        self.assertEqual(
+            str(context_manager.exception),
+            'Error in request. Possibly authentication failed [401]: Not Authorised')
