@@ -1,5 +1,4 @@
 from mock import patch
-from six.moves.urllib.parse import quote
 
 import jenkins
 from tests.base import JenkinsTestBase
@@ -12,18 +11,26 @@ class JenkinsScriptTest(JenkinsTestBase):
         self.j.run_script(u'println(\"Hello World!\")')
 
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('scriptText'))
         self._check_requests(jenkins_mock.call_args_list)
 
+    @patch.object(jenkins.Jenkins, 'jenkins_open')
+    def test_run_script_node(self, jenkins_mock):
+        self.j.run_script(u'println(\"Hello World!\")', node='(master)')
+
+        self.assertEqual(
+            jenkins_mock.call_args[0][0].url,
+            self.make_url('computer/(master)/scriptText'))
+        self._check_requests(jenkins_mock.call_args_list)
+
     @patch.object(jenkins.Jenkins, 'jenkins_open')
     def test_run_script_urlproof(self, jenkins_mock):
         self.j.run_script(u'if (a == b && c ==d) { println(\"Yes\")}')
 
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('scriptText'))
-        self.assertIn(quote('&&'), jenkins_mock.call_args[0][0].data.decode('utf8'))
         self._check_requests(jenkins_mock.call_args_list)
 
     @patch.object(jenkins.Jenkins, 'jenkins_open')
@@ -33,7 +40,7 @@ class JenkinsScriptTest(JenkinsTestBase):
         j = jenkins.Jenkins(self.make_url(''), 'test', 'test')
         j.install_plugin("jabber")
         self.assertEqual(
-            jenkins_mock.call_args[0][0].get_full_url(),
+            jenkins_mock.call_args[0][0].url,
             self.make_url('scriptText'))
         self._check_requests(jenkins_mock.call_args_list)
 
